@@ -3,7 +3,7 @@
 # Author: Edward Kawas <edward.kawas@gmail.com>,
 # For copyright and disclaimer see below.
 #
-# $Id: Class.pm,v 1.9 2010-02-01 15:03:58 ubuntu Exp $
+# $Id: Class.pm,v 1.3 2009-11-13 18:16:00 ubuntu Exp $
 #-----------------------------------------------------------------
 package SADI::Data::OWL::Class;
 use base ("SADI::Base");
@@ -14,7 +14,7 @@ use RDF::Core::Statement;
 
 # add versioning to this module
 use vars qw /$VERSION/;
-$VERSION = sprintf "%d.%02d", q$Revision: 1.9 $ =~ /: (\d+)\.(\d+)/;
+$VERSION = sprintf "%d.%02d", q$Revision: 1.3 $ =~ /: (\d+)\.(\d+)/;
 
 =head1 NAME
 
@@ -48,9 +48,7 @@ Details are in L<SADI::Base>. Here just a list of them:
 
 =over
 
-=item B<label> an optional RDF label for this class
-
-=item B<type> a URI that describes the type of this class
+=item B<type> a URI that describes the type of this clas
 
 =item B<value> a URI to an individual of this class (same as uri, e.g. if you set this, you set value too)
 
@@ -64,9 +62,7 @@ Details are in L<SADI::Base>. Here just a list of them:
 
 {
 	my %_allowed = (
-	   # the RDFS label for this node
-	   label  => { type => SADI::Base->STRING },
-	   type  => { type => SADI::Base->STRING },
+		type  => { type => SADI::Base->STRING },
 		# value and uri are synonyms here
 		value => {
 			type => SADI::Base->STRING,
@@ -85,7 +81,8 @@ Details are in L<SADI::Base>. Here just a list of them:
 		},
 		statements => { type => 'RDF::Core::Statement', is_array => 1 },
 		# used internally / set during _get_statements
-		subject => => { type => 'RDF::Core::Resource' },				
+		subject => => { type => 'RDF::Core::Resource' },
+		
 	);
 
 	sub _accessible {
